TokenInterceptor class

Constructors

TokenInterceptor()

Properties

hashCode int
The hash code for this object.
no setterinherited
pref AppPreferenceService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAppHeader(RequestOptions options) → RequestOptions
addAuthHeader(RequestOptions options) → RequestOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) Future<void>
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited