AppTextStyle class

Constructors

AppTextStyle()
factory

Properties

bodyL TextStyle
fontSize: 18 normal
final
bodyM TextStyle
fontSize: 16 normal
final
bodyS TextStyle
fontSize: 14 normal
final
caption TextStyle
fontSize: 13 w300
final
hashCode int
The hash code for this object.
no setterinherited
headingL TextStyle
fontSize: 34 bold
final
headingM TextStyle
fontSize: 32 w500
final
headingS TextStyle
fontSize: 30 normal
final
headingXL TextStyle
fontSize: 36 bold
final
labelL TextStyle
fontSize: 12 bold
final
labelM TextStyle
fontSize: 11 w500
final
labelProcessComplete TextStyle
fontSize 16, color white
final
labelS TextStyle
fontSize: 10 normal
final
labelTitle TextStyle
fontSize 24, color black bold
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleL TextStyle
fontSize: 28 bold
final
titleM TextStyle
fontSize: 24 w500
final
titleS TextStyle
fontSize: 20 normal
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited