AppPreferenceService class
Constructors
- AppPreferenceService()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAllData(
) → void -
getBool(
String key) → bool -
getDouble(
String key) → double -
getInt(
String key) → int -
getJsonObject(
String key) → Map< String, dynamic> -
getString(
String key) → String -
getStringList(
String key) → List< String> ? -
initialize(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeKey(
String key) → void -
saveJsonObject(
String key, Map< String, dynamic> jsonObject) → Future<bool?> -
saveStringList(
String key, List< String> value) → void -
setBool(
String key, bool value) → void -
setDouble(
String key, double value) → void -
setInt(
String key, int value) → void -
setString(
String key, String value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited