AppUtils class
Constructors
- AppUtils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateTrackId(
) → String -
Generates a unique
trackIdbased on the current timestamp and a random alphanumeric string. -
randomAlphaNumericString(
int length) → String - Generates a random alphanumeric string of the specified length.