ChatDataSourceImpl class

Implemented types

Constructors

ChatDataSourceImpl(dynamic _api)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createConversation(String token) Future<Int64>
override
getConversationMetaData() Future<ConversationMetaData>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerUser(String userId, String name) Future<ChatRegisterUserModel>
override
sendMessage(ChatMessage message) Future<ChatMessage>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited