SizeUnit class
Constructors
- SizeUnit()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- borderRadius → const double
- customAppbarHeight → const double
- customTextFieldBoarderRadius → const double
- defaultScreenPadding → const double
- screenSize375 → const double
- size8 → const double
- size10 → const double
- size11 → const double
- size12 → const double
- size14 → const double
- size16 → const double
- size18 → const double
- size20 → const double
- size22 → const double
- size24 → const double
- size26 → const double
- size28 → const double
- size32 → const double
- size40 → const double
- size42 → const double