AppTextStyle class
Constructors
- AppTextStyle()
-
factory
Properties
- bodyL → TextStyle
-
fontSize: 18
normalfinal - bodyM → TextStyle
-
fontSize: 16
normalfinal - bodyS → TextStyle
-
fontSize: 14
normalfinal - caption → TextStyle
-
fontSize: 13
w300final - hashCode → int
-
The hash code for this object.
no setterinherited
- headingL → TextStyle
-
fontSize: 34
boldfinal - headingM → TextStyle
-
fontSize: 32
w500final - headingS → TextStyle
-
fontSize: 30
normalfinal - headingXL → TextStyle
-
fontSize: 36
boldfinal - labelL → TextStyle
-
fontSize: 12
boldfinal - labelM → TextStyle
-
fontSize: 11
w500final - labelProcessComplete → TextStyle
-
fontSize 16, color white
final
- labelS → TextStyle
-
fontSize: 10
normalfinal - labelTitle → TextStyle
-
fontSize 24, color black bold
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleL → TextStyle
-
fontSize: 28
boldfinal - titleM → TextStyle
-
fontSize: 24
w500final - titleS → TextStyle
-
fontSize: 20
normalfinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited